# -*- coding: utf-8 -*-
# File: __init__.py

# Copyright 2021 Dr. Janis Meyer. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
Init file for eval package. Contains metrics (customized for special tasks), evaluators and tensorpack related callbacks
for training.
"""

from ..utils.file_utils import apted_available
from .accmetric import *
from .base import *
from .cocometric import *
from .eval import *
from .registry import *

if apted_available():
    from .tedsmetric import *
